@@ -10,6 +10,11 @@ test_that("partition basics", {
                  tibble("a=T" = c(T, T, F, F),
                         "a=F" = c(F, F, T, T)))
 
+    expect_equal(partition(data.frame(`a=b,c{x}` = c(T, T, F, F), check.names = FALSE),
+                           .keep = FALSE),
+                 tibble("a_b_c_x_=T" = c(T, T, F, F),
+                        "a_b_c_x_=F" = c(F, F, T, T)))
+
     expect_equal(partition(data.frame(a = c(T, T, F, NA)),
                            .na = TRUE,
                            .keep = FALSE),
@@ -35,6 +40,12 @@ test_that("partition basics", {
                         "a=b" = c(F, T, T, F),
                         "a=c" = c(F, F, F, T)))
 
+    expect_equal(partition(data.frame(a = factor(c("a=a", "{b}", "{b}", "c,d"))),
+                           .keep = FALSE),
+                 tibble("a=a_a" = c(T, F, F, F),
+                        "a=c_d" = c(F, F, F, T),
+                        "a=_b_" = c(F, T, T, F)))
+
     expect_equal(partition(data.frame(a = factor(c("a", "b", "b", "c"))),
                            .keep = TRUE),
                  tibble("a" = factor(c("a", "b", "b", "c")),
@@ -85,6 +96,31 @@ test_that("partition basics", {
 })
 
 
+test_that("partition dummy", {
+    expect_equal(partition(data.frame(a = 1:3),
+                           .keep = FALSE,
+                           .method = "dummy"),
+                 tibble("a=1" = c(T,F,F),
+                        "a=2" = c(F,T,F),
+                        "a=3" = c(F,F,T)))
+
+    expect_equal(partition(data.frame(a = c(1.0, 1.2, 1.2, 1.0, NA)),
+                           .keep = FALSE,
+                           .na = TRUE,
+                           .method = "dummy"),
+                 tibble("a=1" = c(T,F,F,T,F),
+                        "a=1.2" = c(F,T,T,F,F),
+                        "a=NA"  = c(F,F,F,F,T)))
+
+    expect_equal(partition(data.frame(a = c(1.0, 1.2, 1.2, 1.0, NA)),
+                           .keep = FALSE,
+                           .na = FALSE,
+                           .method = "dummy"),
+                 tibble("a=1" = c(T,F,F,T,F),
+                        "a=1.2" = c(F,T,T,F,F)))
+})
+
+
 test_that("partition crisp", {
     expect_equal(partition(data.frame(a = 0:10),
                            .breaks = 2,
@@ -155,6 +191,47 @@ test_that("partition crisp", {
                         "b=BBB" = c(F,F,F,F,T,T,T,F,F,F),
                         "b=cc"  = c(F,F,F,F,F,F,F,T,T,T)))
 
+    expect_equal(partition(data.frame(b = 1:10),
+                           .breaks = c(1, 3, 5, 7, 10),
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .right = TRUE,
+                           .span = 2),
+                 tibble("b=(1;5]"  = c(F,T,T,T,T,F,F,F,F,F),
+                        "b=(3;7]"  = c(F,F,F,T,T,T,T,F,F,F),
+                        "b=(5;10]" = c(F,F,F,F,F,T,T,T,T,T)))
+
+    expect_equal(partition(data.frame(b = 1:10),
+                           .breaks = c(1, 3, 5, 7, 10),
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .right = TRUE,
+                           .span = 2,
+                           .inc = 2),
+                 tibble("b=(1;5]"  = c(F,T,T,T,T,F,F,F,F,F),
+                        "b=(5;10]" = c(F,F,F,F,F,T,T,T,T,T)))
+
+    expect_equal(partition(data.frame(b = 1:10),
+                           .breaks = 1:9,
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .right = TRUE,
+                           .span = 2,
+                           .inc = 3),
+                 tibble("b=(1;3]"  = c(F,T,T,F,F,F,F,F,F,F),
+                        "b=(4;6]" = c(F,F,F,F,T,T,F,F,F,F),
+                        "b=(7;9]" = c(F,F,F,F,F,F,F,T,T,F)))
+
+    expect_equal(partition(data.frame(b = 1:10),
+                           .breaks = c(-Inf, 4, 7, Inf),
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .right = TRUE,
+                           .inc = 2),
+                 tibble("b=(-Inf;4]" = c(T,T,T,T,F,F,F,F,F,F),
+                        "b=(7;Inf]"  = c(F,F,F,F,F,F,F,T,T,T)))
+
+
     expect_error(partition(data.frame(a = 0:10),
                            .method = "crisp"),
                  "`.breaks` must not be NULL in order to partition numeric column `a`")
@@ -164,6 +241,11 @@ test_that("partition crisp", {
                            .method = "crisp"),
                  "If `.breaks` is a single value, it must be a natural number greater than 1.")
 
+    expect_error(partition(data.frame(a = 0:10),
+                           .breaks = 1,
+                           .method = "crisp"),
+                 "If `.breaks` is a single value, it must be a natural number greater than 1.")
+
     expect_error(partition(data.frame(a = 0:10),
                            .breaks = 1.5,
                            .method = "crisp"),
@@ -179,7 +261,35 @@ test_that("partition crisp", {
                            .breaks = c(-Inf, 4, 7, Inf),
                            .method = "crisp",
                            .labels = c("A", "cc")),
-                 "If `.breaks` is non-scalar, the length of `.labels` must be equal to the length of `.breaks` - 1.")
+                 "If `.breaks` is non-scalar, the length of `.labels` must be equal to")
+})
+
+
+test_that("partition crisp styles", {
+    x <- c(1.0, 2.2, 2.4, 2.6, 3, 4, 5, 6, 9)
+    expect_equal(partition(data.frame(a = x),
+                           .breaks = 2,
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .style = "equal"),
+                 tibble("a=(-Inf;5]" = c(T,T,T,T,T,T,T,F,F),
+                        "a=(5;Inf]"  = c(F,F,F,F,F,F,F,T,T)))
+
+    expect_equal(partition(data.frame(a = x),
+                           .breaks = 2,
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .style = "quantile"),
+                 tibble("a=(-Inf;3]" = c(T,T,T,T,T,F,F,F,F),
+                        "a=(3;Inf]"  = c(F,F,F,F,F,T,T,T,T)))
+
+    expect_equal(partition(data.frame(a = x),
+                           .breaks = 2,
+                           .keep = FALSE,
+                           .method = "crisp",
+                           .style = "kmeans"),
+                 tibble("a=(-Inf;4.5]" = c(T,T,T,T,T,T,F,F,F),
+                        "a=(4.5;Inf]"  = c(F,F,F,F,F,F,T,T,T)))
 })
 
 
@@ -199,6 +309,48 @@ test_that("partition triangle", {
                         "a=(0;5;10)"   = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0, 0.8, 0.6, 0.4, 0.2, 0.0),
                         "a=(5;10;Inf)" = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.2, 0.4, 0.6, 0.8, 1.0)))
 
+    expect_equal(partition(data.frame(b = 0:10),
+                           .breaks = c(1, 3, 5, 7, 10),
+                           .keep = FALSE,
+                           .method = "triangle",
+                           .right = TRUE,
+                           .span = 2),
+                 tibble("b=(1;3;5;7)"  = c(0, 0, 0.5, 1, 1, 1, 0.5, 0, 0, 0, 0),
+                        "b=(3;5;7;10)"  = c(0, 0, 0, 0, 0.5, 1, 1, 1, 0.66667, 0.33333, 0)),
+                 tolerance = 1e-3)
+
+    expect_equal(partition(data.frame(b = 0:10),
+                           .breaks = c(1, 3, 5, 7, 9, 10),
+                           .keep = FALSE,
+                           .method = "triangle",
+                           .right = TRUE,
+                           .span = 2,
+                           .inc = 2),
+                 tibble("b=(1;3;5;7)"  = c(0, 0, 0.5, 1, 1, 1, 0.5, 0, 0, 0, 0),
+                        "b=(5;7;9;10)" = c(0, 0, 0, 0, 0, 0, 0.5, 1, 1, 1, 0)))
+
+    expect_equal(partition(data.frame(b = 0:11),
+                           .breaks = 1:10,
+                           .keep = FALSE,
+                           .method = "triangle",
+                           .right = TRUE,
+                           .span = 2,
+                           .inc = 3),
+                 tibble("b=(1;2;3;4)"  = c(0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0),
+                        "b=(4;5;6;7)"  = c(0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0),
+                        "b=(7;8;9;10)" = c(0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0)))
+
+    expect_equal(partition(data.frame(b = 0:10),
+                           .breaks = c(-Inf, 3, 6, 9, Inf),
+                           .keep = FALSE,
+                           .method = "triangle",
+                           .right = TRUE,
+                           .inc = 2),
+                 tibble("b=(-Inf;3;6)" = c(1, 1, 1, 1, 0.6667, 0.3333, 0, 0, 0, 0, 0),
+                        "b=(6;9;Inf)"  = c(0, 0, 0, 0, 0, 0, 0, 0.3333, 0.6667, 1, 1)),
+                 tolerance = 1e-3)
+
+
     expect_error(partition(data.frame(a = 0:10),
                            .breaks = 1,
                            .keep = FALSE,
@@ -221,7 +373,7 @@ test_that("partition triangle", {
                            .breaks = c(-Inf, 4, 7, Inf),
                            .method = "triangle",
                            .labels = c("A", "b", "cc")),
-                 "If `.breaks` is non-scalar, the length of `.labels` must be equal to the length of `.breaks` - 2.")
+                 "If `.breaks` is non-scalar, the length of `.labels` must be equal to")
 })
 
 
@@ -263,7 +415,7 @@ test_that("partition raisedcos", {
                            .breaks = c(-Inf, 4, 7, Inf),
                            .method = "raisedcos",
                            .labels = c("A", "b", "cc")),
-                 "If `.breaks` is non-scalar, the length of `.labels` must be equal to the length of `.breaks` - 2.")
+                 "If `.breaks` is non-scalar, the length of `.labels` must be equal to")
 })
 
 
@@ -287,6 +439,7 @@ test_that("partition errors", {
     expect_error(partition(d, a, .right = "TRUE"),
                  "`.right` must be a flag")
     expect_error(partition(d, a, .method = "foo"),
-                 '`.method` must be equal to one of: "crisp", "triangle", "raisedcos".')
+                 '`.method` must be equal to one of: "dummy", "crisp", "triangle", "raisedcos".')
 
 })
+
