@@ -14,6 +14,8 @@ test_that("var_grid everything on data.frame", {
     expect_equal(colnames(res), c("xvar", "yvar"))
     expect_equal(res$xvar, c("v", "v", "v", "v", "w", "w", "w", "x", "x", "y"))
     expect_equal(res$yvar, c("w", "x", "y", "z", "x", "y", "z", "y", "z", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x", "y", "z"))
+    expect_equal(attr(res, "yvars"), c("v", "w", "x", "y", "z"))
 })
 
 test_that("var_grid everything on data.frame (with custom colnames)", {
@@ -34,6 +36,8 @@ test_that("var_grid everything on data.frame (with custom colnames)", {
     expect_equal(colnames(res), c("blaX", "blaY"))
     expect_equal(res$blaX, c("v", "v", "v", "v", "w", "w", "w", "x", "x", "y"))
     expect_equal(res$blaY, c("w", "x", "y", "z", "x", "y", "z", "y", "z", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x", "y", "z"))
+    expect_equal(attr(res, "yvars"), c("v", "w", "x", "y", "z"))
 })
 
 test_that("var_grid selected on data.frame", {
@@ -50,6 +54,8 @@ test_that("var_grid selected on data.frame", {
     expect_equal(colnames(res), c("xvar", "yvar"))
     expect_equal(res$xvar, c("v", "w", "x"))
     expect_equal(res$yvar, c("z", "z", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x"))
+    expect_equal(attr(res, "yvars"), c("z"))
 })
 
 test_that("var_grid single on data.frame", {
@@ -66,6 +72,8 @@ test_that("var_grid single on data.frame", {
     expect_equal(colnames(res), c("xvar", "yvar"))
     expect_equal(res$xvar, c("v"))
     expect_equal(res$yvar, c("x"))
+    expect_equal(attr(res, "xvars"), c("v"))
+    expect_equal(attr(res, "yvars"), c("x"))
 })
 
 test_that("var_grid everything on matrix", {
@@ -79,6 +87,8 @@ test_that("var_grid everything on matrix", {
     expect_equal(colnames(res), c("xvar", "yvar"))
     expect_equal(res$xvar, c("v", "v", "v", "v", "w", "w", "w", "x", "x", "y"))
     expect_equal(res$yvar, c("w", "x", "y", "z", "x", "y", "z", "y", "z", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x", "y", "z"))
+    expect_equal(attr(res, "yvars"), c("v", "w", "x", "y", "z"))
 })
 
 test_that("var_grid only xvar", {
@@ -96,8 +106,41 @@ test_that("var_grid only xvar", {
     expect_equal(nrow(res), 5)
     expect_equal(colnames(res), "var")
     expect_equal(res$var, c("v", "w", "x", "y", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x", "y", "z"))
+    expect_null(attr(res, "yvars"))
 })
 
+test_that("var_grid with disjoint", {
+    d <- data.frame(v = FALSE,
+                    w = FALSE,
+                    x = TRUE,
+                    y = c(TRUE, FALSE),
+                    z = c(TRUE, FALSE))
+
+    res <- var_grid(d,
+                    xvars = everything(),
+                    yvars = everything())
+
+    expect_true(is_tibble(res))
+    expect_equal(nrow(res), 10)
+    expect_equal(colnames(res), c("xvar", "yvar"))
+    expect_equal(res$xvar, c("v", "v", "v", "v", "w", "w", "w", "x", "x", "y"))
+    expect_equal(res$yvar, c("w", "x", "y", "z", "x", "y", "z", "y", "z", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x", "y", "z"))
+    expect_equal(attr(res, "yvars"), c("v", "w", "x", "y", "z"))
+
+    res <- var_grid(d,
+                    xvars = everything(),
+                    yvars = everything(),
+                    disjoint = c("vw", "vw", "xyz", "xyz", "xyz"))
+
+    expect_equal(nrow(res), 6)
+    expect_equal(colnames(res), c("xvar", "yvar"))
+    expect_equal(res$xvar, c("v", "v", "v", "w", "w", "w"))
+    expect_equal(res$yvar, c("x", "y", "z", "x", "y", "z"))
+    expect_equal(attr(res, "xvars"), c("v", "w", "x", "y", "z"))
+    expect_equal(attr(res, "yvars"), c("v", "w", "x", "y", "z"))
+})
 
 test_that("var_grid errors", {
     d <- data.frame(v = FALSE,
@@ -121,4 +164,11 @@ test_that("var_grid errors", {
                           xvars = everything(),
                           yvars = everything()),
                  "`x` must be a matrix or a data frame")
+
+    expect_error(var_grid(d, xvars = everything(), yvars = everything(),
+                          disjoint = list("x")),
+                 "`disjoint` must be a plain vector")
+    expect_error(var_grid(d, xvars = everything(), yvars = everything(),
+                          disjoint = "x"),
+                 "The length of `disjoint` must be 0 or must be equal to the number of columns in `x`.")
 })
